/*
 * Copyright (C) 2012 ALT Linux
 *
 * Contact: Paul Wolneykien <manowar@altlinux.ru>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#include <QCoreApplication>
#include <QString>
#include <QStringList>
#include <QMap>
#include <QDebug>
#include <stdlib.h>
#include "propertylistener.h"
#include <X11/Xlib.h>
#include <X11/extensions/Xrandr.h>

int
align_screen (Display *display,
	      Window root,
	      Rotation rot)
{
  int ret;
  XRRScreenConfiguration *sconf;
  SizeID ssize;
  Rotation crot;
  Status status;

  sconf = XRRGetScreenInfo (display, root);
  ssize = XRRConfigCurrentConfiguration (sconf, &crot);

  ret = EXIT_SUCCESS;
  if (rot != crot) {
    status = XRRSetScreenConfig (display, sconf, root, ssize, rot, CurrentTime);
    if (status != RRSetConfigSuccess) {
      ret = EXIT_FAILURE;
    }
  }

  XRRFreeScreenConfigInfo (sconf);

  return ret;
}

void top_change (QVariant *val)
{
    Display *display = XOpenDisplay(NULL);
    Window root = RootWindow (display, DefaultScreen(display));
    
    if (val->toString().compare ("left") == 0) {
        align_screen (display, root, RR_Rotate_90);
    } else if (val->toString().compare ("bottom") == 0) {
        align_screen (display, root, RR_Rotate_180);
    } else if (val->toString().compare ("right") == 0) {
        align_screen (display, root, RR_Rotate_270);
    } else {
        align_screen (display, root, RR_Rotate_0);
    }
}

int main(int argc, char **argv)
{
    QCoreApplication app (argc, argv);
    PropertyListener topedge ("Screen.TopEdge", top_change);
    return app.exec();
}
